const hasLocalStorage = typeof window !== 'undefined' && !!window.localStorage;
const set = (key, data) => {
    if (!hasLocalStorage)
        return undefined;
    try {
        const string = typeof data === 'string' ? data : JSON.stringify(data);
        return localStorage.setItem(key, string);
    }
    catch (err) {
        return undefined;
    }
};
const get = (key) => {
    if (!hasLocalStorage)
        return undefined;
    const data = localStorage.getItem(key);
    if (!data)
        return data;
    try {
        return JSON.parse(data);
    }
    catch (err) {
        // So we return whatever we've got on a failure
        // E.g. the data could be a plain string, which errors on JSON.parse.
        return data;
    }
};

export { get, set };
